Learn R Programming

modeltime (version 0.1.0)

mdl_time_refit: Modeltime Refit Helpers

Description

Used for low-level refitting of modeltime, parnsip and workflow models These functions are not intended for user use.

Usage

mdl_time_refit(object, data, ..., control = NULL)

Arguments

object

A Modeltime Table

data

A tibble that contains data to retrain the model(s) using.

...

Additional arguments passed to fit().

control

Either control_parsnip() or control_workflow() depending on the object. If NULL, created automatically.

Value

A tibble with forecast features