update_model_description: Update the model description by model id in a Modeltime Table
Description
Update the model description by model id in a Modeltime Table
Usage
update_model_description(object, .model_id, .new_model_desc)
Arguments
.model_id
A numeric value matching the .model_id that you want to update
.new_model_desc
Text describing the new model description