Learn R Programming

modeltime (version 0.1.0)

mdl_time_forecast: Modeltime Forecast Helpers

Description

Used for low-level forecasting of modeltime, parnsip and workflow models. These functions are not intended for user use.

Usage

mdl_time_forecast(
  object,
  calibration_data,
  new_data = NULL,
  h = NULL,
  actual_data = NULL,
  bind_actual = TRUE,
  ...
)

Arguments

object

A Modeltime Table

calibration_data

Data that has been calibrated from a testing set

new_data

A tibble containing future information to forecast. If NULL, forecasts the calibration data.

h

The forecast horizon (can be used instead of new_data for time series with no exogenous regressors). Extends the calibration data h periods into the future.

actual_data

Reference data that is combined with the output tibble and given a .key = "actual"

bind_actual

Logical. Whether or not to skip rowwise binding of `actual_data``

...

Not currently used

Value

A tibble with forecast features