Used for low-level forecasting of modeltime, parnsip and workflow models. These functions are not intended for user use.
mdl_time_forecast(
object,
calibration_data,
new_data = NULL,
h = NULL,
actual_data = NULL,
bind_actual = TRUE,
...
)A Modeltime Table
Data that has been calibrated from a testing set
A tibble containing future information to forecast.
If NULL, forecasts the calibration data.
The forecast horizon (can be used instead of new_data for
time series with no exogenous regressors).
Extends the calibration data h periods into the future.
Reference data that is combined with the output tibble and given a .key = "actual"
Logical. Whether or not to skip rowwise binding of `actual_data``
Not currently used
A tibble with forecast features