Used for low-level refitting of modeltime, parnsip and workflow models These functions are not intended for user use.
mdl_time_refit(object, data, ..., control = NULL)A Modeltime Table
A tibble that contains data to retrain the model(s) using.
Additional arguments passed to fit().
Either control_parsnip() or control_workflow() depending on the object.
If NULL, created automatically.
A tibble with forecast features